@@ -2,16 +2,17 @@
 
 % Copyright Notice
 %
+%    Copyright (C) 2015, 2020 CentraleSupelec
 %    Copyright (C) 2014 SUPELEC
 %
-%    Author:  Julien Bect  <julien.bect@supelec.fr>
+%    Author:  Julien Bect  <julien.bect@centralesupelec.fr>
 
 % Copying Permission Statement
 %
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -29,13 +30,14 @@
 function fn = fieldnames (x)
 
 fn = fieldnames (x.stk_dataframe);
-fn = [{'levels' 'stk_dataframe'} fn];
+fn = [{'levels'; 'stk_dataframe'}; fn];
+
+end % function
 
-end % function fieldnames
 
 %!test
-%! x = stk_factorialdesign ({0:1, 3:5}, {'u' 'v'})
+%! x = stk_factorialdesign ({0:1, 3:5}, {'u' 'v'});
 %! fn1 = sort (fieldnames (x));
-%! fn2 = {'colnames', 'data', 'info', 'levels', ...
-%!        'rownames', 'stk_dataframe', 'u', 'v'};
+%! fn2 = {'colnames'; 'data'; 'info'; 'levels'; ...
+%!        'rownames'; 'sample_size'; 'stk_dataframe'; 'u'; 'v'};
 %! assert (isequal (fn1, fn2));
