@@ -16,7 +16,7 @@
 
 % Copyright Notice
 %
-%    Copyright (C) 2015 CentraleSupelec
+%    Copyright (C) 2015, 2018, 2021 CentraleSupelec
 %    Copyright (C) 2014 SUPELEC & A. Ravisankar
 %
 %    Authors:  Julien Bect        <julien.bect@centralesupelec.fr>
@@ -27,7 +27,7 @@
 %    This file is part of
 %
 %            STK: a Small (Matlab/Octave) Toolbox for Kriging
-%               (http://sourceforge.net/projects/kriging)
+%               (https://github.com/stk-kriging/stk/)
 %
 %    STK is free software: you can redistribute it and/or modify it under
 %    the terms of the GNU General Public License as published by the Free
@@ -42,15 +42,11 @@
 %    You should  have received a copy  of the GNU  General Public License
 %    along with STK.  If not, see <http://www.gnu.org/licenses/>.
 
-function [u_opt,lik] = stk_minimize_boxconstrained (algo, f, u_init, lb, ub)
-
-if nargin>5
-    stk_error ('Too many input arguments.', 'TooManyInputArgs');
-end
+function [u_opt, lik] = stk_minimize_boxconstrained (algo, f, u_init, lb, ub)
 
 nabla_f = @(u)(nabla_f_ (f, u));
 
-[u_opt,lik] = feval (algo.sqp, u_init, {f nabla_f}, [] , [], lb, ub, ...
+[u_opt, lik] = feval (algo.sqp, u_init, {f nabla_f}, [], [], lb, ub, ...
     algo.options.maxiter, algo.options.tol);
 
 end % function
@@ -61,6 +57,6 @@ function df = nabla_f_ (f, u)
 % Note: with this implementation, f_val is computed twice
 %   (once when f is called by sqp, and once again when nabla_f is called)
 
-[ignd, df] = f (u);  %#ok<ASGLU> CG#07
+[~, df] = f (u);
 
 end % function
